;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "with-editor" "20260417.751"
  "Use the Emacsclient as $EDITOR."
  '((emacs  "26.1")
    (compat "30.1"))
  :url "https://github.com/magit/with-editor"
  :commit "d0935036eb894680d8ca1a4d1ed8e8d5d90005e5"
  :revdesc "d0935036eb89"
  :keywords '("processes" "terminals")
  :authors '(("Jonas Bernoulli" . "emacs.with-editor@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.with-editor@jonas.bernoulli.dev")))
